========
Top Hack
========

Get top links from HN


* Free software: MIT license

Usage guide
-----------

Install with pip

    pip install tophack

or

    pip install --user tophack

Then run `tophack` from the terminal.

Select the number of the entry you like.

You will be asked for **o/c/q**.

- **o** means open the url in your web browser.
- **c** means open the HN comments.
- **q** means quit and choose another submission.

You can customise using CLI arguments. Type
`tophack -h` to view all options.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
